#!/usr/bin/env python  # pylint: disable=invalid-name
# -*- coding: utf-8 -*-

import os
import json
import time
import click

from aiida.engine import run
from aiida.engine import submit
from aiida.plugins import DataFactory, WorkflowFactory
from aiida.orm import Code, Dict

# Workchain objects
MulticompGcmcWorkChain = WorkflowFactory('lsmo.multicomp_gcmc')  # pylint: disable=invalid-name

# Data objects
CifData = DataFactory('cif')  # pylint: disable=invalid-name
NetworkParameters = DataFactory('zeopp.parameters')  # pylint: disable=invalid-name
SinglefileData = DataFactory('singlefile')


@click.command('cli')
@click.argument('raspa_code_label')
@click.argument('zeopp_code_label')
def main(raspa_code_label, zeopp_code_label):
    """Prepare inputs and submit the workchain.
    Usage: verdi run binary.py raspa-4467e14@fidis-serial zeopp-46ce745@fidis-serial"""

    builder = MulticompGcmcWorkChain.get_builder()

    builder.metadata.label = 'IAST/Binary/'

    builder.raspa_base.raspa.code = Code.get_from_string(raspa_code_label)
    builder.zeopp.code = Code.get_from_string(zeopp_code_label)

    options = {
        'resources': {
            'num_machines': 1,
            'tot_num_mpiprocs': 1,
        },
        'max_wallclock_seconds': 24 * 60 * 60,
        'withmpi': False,
    }
    builder.raspa_base.raspa.metadata.options = options
    builder.zeopp.metadata.options = options

    pathstructures = os.getcwd()
    structures = []
    for f in os.listdir(pathstructures + "/IAST"):
        if f.endswith(".cif"):
            structures.append(f.split('.')[0])
    
    pkslist = []
    strucorder = []
    
    for i in range(len(structures)):
        time.sleep(3)
        builder.structure = CifData(file=os.path.abspath('IAST/' + structures[i] + '.cif'), label= structures[i])
        builder.conditions = Dict(dict={
            'molfraction': {
                'co2': 0.1521,
                'n2': 0.8479,
            },
            'temp_press': [
                [298.15, 1.01325]
            ]   
        })

        builder.parameters = Dict(
                dict={
                    'zeopp_probe_scaling': 0.0,
                    'zeopp_block_samples': 100,  # Default: 100
                    'raspa_gcmc_init_cycles': 1000,  # Default: 1e3
                    'raspa_gcmc_prod_cycles': 10000,  # Default: 1e4
                    })

        wc = submit(builder)
        strucorder.append(structures[i])
        pkslist.append(wc.pk)

    Reference = {
            "Structure" : strucorder,
            "PK" : pkslist
         }

    with open("binaryPP.json", "w") as outfile:
        json.dump(Reference, outfile)
    outfile.close()

if __name__ == '__main__':
    main()  # pylint: disable=no-value-for-parameter

# EOF
