#!/usr/bin/env python  # pylint: disable=invalid-name
# -*- coding: utf-8 -*-
import json
import os
import click
import time

from aiida.engine import run
from aiida.engine import submit
from aiida.plugins import DataFactory, WorkflowFactory
from aiida.orm import Code, Dict, Str

# Workchain objects
IsothermAccurateWorkChain = WorkflowFactory('lsmo.isotherm_accurate')  # pylint: disable=invalid-name

# Data objects
CifData = DataFactory('cif')  # pylint: disable=invalid-name
NetworkParameters = DataFactory('zeopp.parameters')  # pylint: disable=invalid-name


@click.command('cli')
@click.argument('raspa_code_label')
@click.argument('zeopp_code_label')
def main(raspa_code_label, zeopp_code_label):
    """Prepare inputs and submit the Isotherm workchain
    Usage: verdi run pci_n2.py raspa-4467e14@fidis-serial zeopp-46ce745@fidis-serial"""

    builder = IsothermAccurateWorkChain.get_builder()
    
    builder.metadata.label = 'IAST/N2/PureIsotherm'

    builder.raspa_base.raspa.code = Code.get_from_string(raspa_code_label)
    builder.zeopp.code = Code.get_from_string(zeopp_code_label)

    options = {
        'resources': {
            'num_machines': 1,
            'tot_num_mpiprocs': 1,
        },
        'max_wallclock_seconds': 24 * 60 * 60,
        'withmpi': False,
    }

    builder.raspa_base.raspa.metadata.options = options
    builder.zeopp.metadata.options = options
    
    pathstructures = os.getcwd()
    structures = []
    for f in os.listdir(pathstructures + "/IAST"):
        if f.endswith(".cif"):
            structures.append(f.split('.')[0])
    
    pkslist = []
    strucorder = []

    for i in range(len(structures)):
        time.sleep(3)
        builder.structure = CifData(file=os.path.abspath('IAST/' + structures[i] + '.cif'), label= structures[i])
        builder.molecule = Dict(
            dict={
                'name': 'N2',
                'forcefield': 'TraPPE',
                'molsatdens': 28.3,
                'proberad': 1.655,
                'singlebead': False,
                'charged': True,
            })

        builder.parameters = Dict(
            dict={
                'ff_framework': 'UFF',  # Default: UFF
                'ff_cutoff': 12,  # To speed up
                'temperature': 298.15,  # (K) Note: higher temperature will have less adsorbate and it is faster
                'zeopp_probe_scaling': 0.8,
                'zeopp_volpo_samples': 100000,  # Default: 1e5 *NOTE: default is good for standard real-case!
                'zeopp_block_samples': 100,  # Default: 100
                'raspa_widom_cycles': 100000,  # Default: 1e5
                'raspa_gcmc_init_cycles': 1000,  # Default: 1e3
                'raspa_gcmc_prod_cycles': 10000,  # Default: 1e4
                'loading_lowp_epsilon': 0.075, # Default: 0.1
                'p_sat_coeff': 1.1, # Default: 1
            })

        wc = submit(builder)
        strucorder.append(structures[i])
        pkslist.append(wc.pk)

    Reference = {
            "Structure" : strucorder,
            "PK" : pkslist
            }

    with open("pure_n2.json", "w") as outfile:
        json.dump(Reference, outfile)
    outfile.close()

if __name__ == '__main__':
    main()  # pylint: disable=no-value-for-parameter

# EOF
